==> android-sdk-core-3.5.2-sources.jar: com/vk/api/sdk/utils/ApiExt.kt <==
/*******************************************************************************
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 vk.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/

package com.vk.api.sdk.utils

import android.net.Uri
import com.vk.api.sdk.VKApiConfig
import com.vk.api.sdk.exceptions.VKApiCodes
import com.vk.api.sdk.internal.VKErrorUtils
import org.json.JSONObject

internal fun JSONObject.hasExecuteError(ignoredErrors: IntArray?) = VKErrorUtils.hasExecuteError(this, ignoredErrors)
internal fun JSONObject.hasSimpleError() = VKErrorUtils.hasSimpleError(this)
internal fun JSONObject.toSimpleError(method: String? = null, accessToken: String? = null) =
    VKErrorUtils.parseSimpleError(optJSONObject(VKApiCodes.PARAM_ERROR) ?: this, method, accessToken)
internal fun JSONObject.toExecuteError(method: String, ignoredErrors: IntArray?) = VKErrorUtils.parseExecuteError(this, method, ignoredErrors)

operator fun <E> androidx.collection.LongSparseArray<E>.set(key: Long, value: E) = put(key, value)

fun Uri.isOAuthBlank() = VKApiConfig.DEFAULT_OAUTH_DOMAIN == host && "/blank.html" == path

==> android-sdk-core-4.1.0-sources.jar: com/vk/api/sdk/utils/ApiExt.kt <==
/*******************************************************************************
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 vk.com
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/

package com.vk.api.sdk.utils

import android.net.Uri
import com.vk.api.sdk.VKApiConfig
import com.vk.api.sdk.exceptions.VKApiCodes
import com.vk.api.sdk.internal.VKErrorUtils
import org.json.JSONObject

internal fun JSONObject.hasExecuteError(ignoredErrors: IntArray?) = VKErrorUtils.hasExecuteError(this, ignoredErrors)
internal fun JSONObject.hasSimpleError() = VKErrorUtils.hasSimpleError(this)
internal fun JSONObject.toSimpleError(method: String? = null, accessToken: String? = null) =
    VKErrorUtils.parseSimpleError(optJSONObject(VKApiCodes.PARAM_ERROR) ?: this, method, accessToken)
internal fun JSONObject.toExecuteError(method: String, ignoredErrors: IntArray?) = VKErrorUtils.parseExecuteError(this, method, ignoredErrors)

operator fun <E> androidx.collection.LongSparseArray<E>.set(key: Long, value: E) = put(key, value)

fun Uri.isOAuthBlank() = VKApiConfig.DEFAULT_OAUTH_WEB_DOMAIN == host && "/blank.html" == path
